@@ -1,3 +1,5 @@
 from .dummy_queue import DummyQueue
 from .redis_queue import RedisQueue
 from .mongo_queue import MongoQueue
+from .task import BaseTask
+from .worker import BaseWorker
